      FUNCTION ABH2O(T,P,RHO,F)
C
C  NAME- abh2o_22sd.f    LANGUAGE- FORTRAN 77
C
C PURPOSE- COMPUTE ABSORPTION COEF IN ATMOSPHERE DUE TO WATER VAPOR
C This version should not be used with a line list older than June 2018,
c nor the new list with an older version of this subroutine.
C 
      IMPLICIT NONE
C  CALLING SEQUENCE PARAMETERS-
C    SPECIFICATIONS
      REAL T,P,RHO,F,ABH2O
C      NAME    UNITS    I/O  DESCRIPTON            VALID RANGE
C      T       KELVIN    I   TEMPERATURE
C      P       MILLIBAR  I   PRESSURE              .1 TO 1000
C      RHO     G/M**3    I   WATER VAPOR DENSITY
C      F       GHZ       I   FREQUENCY             
C      ABH2O   NEPERS/KM O   POWER ABSORPTION COEFFICIENT
C
C   Multiply ABH2O by 4.343 to obtain dB/km.
c
c   Line parameters will be read from file h2o_list.asc; intensities should
c   include the isotope abundance factors.
C   This version uses a line-shape cutoff and calculates speed-dependence,
C    but only for the 22.235 GHz line.
C
C   REVISION HISTORY-
C    DATE- OCT.6, 1988 EQS AS PUBL.: P.W. Rosenkranz, CHAP. 2 in 
C     ATMOSPHERIC REMOTE SENSING BY MICROWAVE RADIOMETRY 
C     (M.A. Janssen, ed., 1993) (http://hdl.handle.net/1721.1/68611).
C     OCT.4, 1995  PWR- USE CLOUGH'S DEFINITION OF LOCAL LINE
C                   CONTRIBUTION,  HITRAN INTENSITIES, ADD 7 LINES.
C     OCT. 24, 95  PWR -ADD 1 LINE.
C     JULY 7, 97   PWR -SEPARATE COEFF. FOR SELF-BROADENING, 
C                       REVISED CONTINUUM.
C     Mar. 2, 2003   PWR - LINE SHIFT
c     Nov. 3, 2012 intensities at base T=296K, get line param. from file.
c     Aug. 6, 2015 read continuum param from the file also. 
c     June 19, 2018 changed file format, separate shift for self & foreign gas
c     Dec. 11, 2018 speed-dependent parameters only for 22 Ghz line;
c      ref: Rosenkranz and Cimini, in preparation 2019.
C
C   LOCAL VARIABLES:
      INTEGER NLINES,I,J,MAXLINES
      PARAMETER (MAXLINES=100)
      REAL DF(2),S1(MAXLINES),B2(MAXLINES),W3(MAXLINES),FL(MAXLINES),
     & WS(MAXLINES),X(MAXLINES),XS(MAXLINES),SH(MAXLINES),SHS(MAXLINES),
     & XH(MAXLINES),XHS(MAXLINES)
      REAL PVAP,PDA,DEN,TI,TI2,SUM,WIDTH0,WIDTH2,WSQ,S,BASE,RES,CON
      REAL SHIFT,SHIFTS,SHIFTF,SAIR,SSELF,R0VS,R0VF,R2VS,R2VF
      REAL WIDTHF,WIDTHS,WAIR,WSELF,REFTLINE,REFTCON,CF,CS,XCF,XCS
      REAL R(4)
      double complex dcerror,Xc,Xrt,pxw,A
      SAVE NLINES,S1,B2,W3,FL,WS,X,XS,SH,INIT,REFTLINE,REFTCON,
     & CF,CS,XCF,XCS,SHS,XH,XHS,R
      LOGICAL INIT
      CHARACTER*4 HEAD
      DATA INIT/.TRUE./
c  correction factors (rel. to best-fit Voigt) for speed-dependence at 22 GHz:
      DATA R/1.0153,.1612, 1.0258,.1440/ !r0air, r2air, r0self, r2self
C
C   initialization section
      IF(INIT) THEN
        OPEN(80,FILE='h2o_list.asc',
     &   STATUS='OLD',FORM='FORMATTED')
        REFTLINE = 296. !reference T for lines
        READ(80,1) HEAD !header for linedata
1       FORMAT(A4)
        DO I=1,MAXLINES
C    read line parameters; units: GHz, Hz*cm^2, MHz/mb
          READ(80,2) FL(i),S1(i),B2(i),Wair,X(i),Wself,Xs(i),
     &     Sair,Xh(I),Sself,Xhs(I)
2         FORMAT(4X,F12.4,E12.4,F7.3,4(F7.3,F6.2))
          IF(FL(I) .LE. 0.) GOTO 10
          NLINES = I
          W3(I) = Wair/1000. !convert to GHz/mb
          WS(I) = Wself/1000.
          SH(I) = Sair/1000.
          SHS(I) = Sself/1000.
          IF(Xh(I).LE.0.) Xh(I) = X(I)
          IF(Xhs(I).LE.0.) Xhs(I) = Xs(I)
        END DO
        WRITE(*,*) 'WARNING: maximum H2O lines reached'
10      CONTINUE
C    read continuum parameters; units: Kelvin, 1/(km*mb^2*GHz^2)
        READ(80,3) REFTCON,CF,Xcf,CS,Xcs
3       FORMAT(20X,F15.0,E9.2,F4.1,E7.2,F6.2)
        CLOSE(80)
        INIT = .FALSE.
        WRITE(*,*) NLINES,' H2O lines used'
      ENDIF
C
      IF(RHO.LE.0.) THEN
        ABH2O = 0.
        RETURN
      ENDIF
      PVAP = RHO*T/216.68
      PDA = P -PVAP
      DEN = 3.344E16*RHO  
C
C      CONTINUUM TERMS
      TI = REFTCON/T
c   Xcf and Xcs include 3 for density & stimulated emission
      CON = (CF*PDA*TI**XCF + CS*PVAP*TI**XCS)*PVAP*F*F 
C
C      ADD RESONANCES
      TI = REFTLINE/T
      TI2 = TI**2.5
      SUM = 0.
      DO 30 I=1,NLINES
      WIDTHF = W3(I)*PDA*TI**X(I)
      WIDTHS = WS(I)*PVAP*TI**XS(I)
      IF(I.EQ.1) THEN
        WIDTH0 = WIDTHF*R(1) + WIDTHS*R(3)
        WIDTH2 = WIDTHF*R(2) + WIDTHS*R(4)
      ELSE
        WIDTH0 = WIDTHF + WIDTHS
        WIDTH2 = 0.
      ENDIF
      SHIFTF = SH(I)*PDA*TI**XH(I)
      SHIFTS = SHS(I)*PVAP*TI**XHS(I)
      SHIFT = SHIFTF + SHIFTS
c     SHIFT2 is too small to measure
      WSQ = WIDTH0**2
c  line intensities include isotopic abundance
      S = S1(I)*TI2*EXP(B2(I)*(1.-TI)) 
      DF(1) = F - FL(I) - SHIFT
      DF(2) = F + FL(I) + SHIFT
C  USE CLOUGH'S DEFINITION OF LOCAL LINE CONTRIBUTION
      BASE = WIDTH0/(562500. + WSQ)
C  DO FOR POSITIVE AND NEGATIVE RESONANCES
      RES = 0.
      DO  J=1,2
       IF(I.EQ.1 .AND. J.EQ.1 .AND. ABS(DF(J)).LT.10.*WIDTH0) THEN
C      speed-dependent resonant shape factor
         Xc = cmplx((WIDTH0-1.5*WIDTH2),DF(J))/WIDTH2
         Xrt = cdsqrt(Xc)
         pxw = 1.77245385090551603d0*Xrt*dcerror(-dimag(Xrt),dble(Xrt))
         A = 2.d0*(1.d0-pxw)/WIDTH2
         RES = RES + REAL(A) - BASE
       ELSEIF(ABS(DF(J)).LT.750.) THEN
         RES = RES + WIDTH0/(DF(J)**2+WSQ) - BASE
       ENDIF
      END DO
30    SUM = SUM + S*RES*(F/FL(I))**2
C    1/PI = .31831
      ABH2O = .31831E-4*DEN*SUM + CON
      RETURN
      END
